gecimi
------

About
-----

gecimi is a python sdk of gecimi.com.

Install
-------

pip install gecimi

Usage
-----

    import gecimi

    lyric = gecimi.Lyric('海阔天空')
    print lyric.get()
    lyric = gecimi.Lyric('不再犹豫', 'Beyond')
    print lyric.get()

License
-------

MIT
